@@ -24,7 +24,6 @@
 #include <QObject>
 #include <QString>
 
-class KPixmapCache;
 class QSvgRenderer;
 class QPixmap;
 class QPainter;
@@ -56,7 +55,7 @@ public:
     /**
      * Enumeration of all possible renderable scene element types.
      */
-    enum Element {
+    enum class Element {
         Background = 1,
         Board,
         HandicapMark,
@@ -121,7 +120,6 @@ signals:
 private:
     QString m_currentTheme;         ///< Holds the current seleted theme
     QSvgRenderer *m_renderer;       ///< Converts SVG parts into pixmaps
-    KPixmapCache *m_cache;          ///< Stores pixmaps efficiently
 };
 
 } // End of namespace Kigo
